@@ -59,3 +59,23 @@ class File(Entity):
 
         data = self.getData()
         open(filepath, "wb").write(data)
+
+    def export(self, path):
+        """
+        Export the file to the directory specified. 
+
+        Paramers
+        -------
+        path (str)
+            The path to the directory to save the file.
+
+        Example
+        -------
+        ::
+
+            file = user.getFile(17000)
+            file.export('/my_folder')
+        """
+        from labstep.entities.file.repository import fileRepository
+
+        return fileRepository.exportFile(self, path)
