@@ -88,6 +88,7 @@ class EntityRepository:
         return entity
 
     def exportEntity(self, entity, rootPath):
+
         from labstep.entities.file.model import File
 
         entityDir = Path(rootPath).joinpath(
@@ -99,16 +100,15 @@ class EntityRepository:
             json.dump(entity.__data__, out, indent=2)
 
         if hasattr(entity, 'file') and entity.file is not None:
-            lsFile = entity.file
-            fileDir = entityDir.joinpath(f'files/{str(lsFile["id"])}')
-            fileDir.mkdir(parents=True, exist_ok=True)
-            File(lsFile, entity.__user__).save(fileDir)
+            lsFile = File(entity.file, entity.__user__)
+            fileDir = entityDir.joinpath('files')
+            lsFile.export(fileDir)
 
         if hasattr(entity, 'files') and entity.files is not None:
-            for lsFile in entity.files:
-                fileDir = entityDir.joinpath(f'files/{str(lsFile["id"])}')
-                fileDir.mkdir(parents=True, exist_ok=True)
-                File(lsFile, entity.__user__).save(fileDir)
+            for file in entity.files:
+                lsFile = File(file, entity.__user__)
+                fileDir = entityDir.joinpath('files')
+                lsFile.export(fileDir)
 
         return entityDir
 
