@@ -11,3 +11,8 @@ API_ROOT = os.getenv("LABSTEP_API_URL")
 if API_ROOT is None:
 
     API_ROOT = 'https://api.labstep.com'
+
+
+if API_ROOT != 'https://api.labstep.com':
+
+    print('Connecting to Labstep API at: ',API_ROOT)
\ No newline at end of file
